===========================
:mod:`oujago.nlp.fjconvert`
===========================

.. automodule:: oujago.nlp.fjconvert

.. autosummary::

    FJConvert


Detailed Description
--------------------


.. autoclass:: FJConvert
    :members:








